@@ -156,7 +156,6 @@ def main():
         r = api.user_service.change_password(userId, 'a')
         assert not r.success
 
-        user_groups = ['gr001', 'gr002']
         user_names = Names({
                 'givenName' : 'First Name',
                 'middleName' : 'Middle Name',
@@ -183,7 +182,6 @@ def main():
 
         user_consents = Consents({'marketingEmail' : True})
 
-        user.memberOf   = user_groups
         user.consents   = user_consents
         user.emails     = user_emails
         user.mobiles    = user_mobiles
@@ -207,7 +205,6 @@ def main():
         assert user.mobiles[1].serialize() == user_mobiles[1].serialize()
         assert user.addresses[0].serialize() == user_addresses[0].serialize()
         assert user.name.serialize() == user_names.serialize()
-        assert len(user.memberOf) == 2
 
         enterprise = Enterprise({'businessId' : 'testId'})
 
@@ -239,8 +236,6 @@ def main():
         groups = api.group_service.get_all(filt).resources
         group_ids = user.memberOf
 
-        assert len(groups) == len(user_groups)
-
         new_group = Group({'name'       : 'gr003',
                           'description' : 'test description',
                           'nsCode'      : nsCode})
