@@ -176,7 +176,6 @@ def main():
 
         user_consents = Consents({'marketingEmail' : True})
 
-        user.memberOf   = user_groups
         user.consents   = user_consents
         user.emails     = user_emails
         user.mobiles    = user_mobiles
@@ -200,7 +199,6 @@ def main():
         assert user2.mobiles[1].serialize() == user_mobiles[1].serialize()
         assert user2.addresses[0].serialize() == user_addresses[0].serialize()
         assert user2.name.serialize() == user_names.serialize()
-        assert len(user2.memberOf) == 2
 
         enterprise = Enterprise({'businessId' : 'testId'})
 
@@ -281,9 +279,6 @@ def main():
 
         filt = Filter(Filter.EQUAL, 'nsCode', nsCode)
         groups = api.group_service.get_all(filt).resources
-        group_ids = user.memberOf
-
-        assert len(groups) == len(user_groups)
 
         new_group = Group({'name'       : 'gr003',
                           'description' : 'test description',
