@@ -74,7 +74,7 @@ class ContractService(object):
                                           auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} contracts'
+            logging.debug('Found {} contracts'
                                 .format(len(response.json()['resources'])))
             contracts = []
             for c in response.json()['resources']:
@@ -106,7 +106,7 @@ class ContractService(object):
 
         if response.status_code == 201:
             contr = Contract(response.json())
-            logging.info('Successfully created contract with id {}'.format(
+            logging.debug('Successfully created contract with id {}'.format(
                                 contr.id))
             return contr
         else:
@@ -126,7 +126,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found contract with id {}'.format(contractId))
+            logging.debug('Found contract with id {}'.format(contractId))
             return Contract(response.json())
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -158,7 +158,7 @@ class ContractService(object):
 
         if response.status_code is 200:
             contr = Contract(response.json())
-            logging.info('Successfully modified contract with the id {}'
+            logging.debug('Successfully modified contract with the id {}'
                         .format(contr.id))
             return contr
         else:
@@ -177,7 +177,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted contract with id {}'
+            logging.debug('Successfully deleted contract with id {}'
                                                 .format(contractId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -197,7 +197,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found allowed actions for the contract {}'
+            logging.debug('Found allowed actions for the contract {}'
                                                 .format(contractId))
             return response.json()
         else:
@@ -220,7 +220,7 @@ class ContractService(object):
 
         if response.status_code == 200:
             contr = Contract(response.json())
-            logging.info('Successfully finalised contract with id {}'.format(
+            logging.debug('Successfully finalised contract with id {}'.format(
                                 contr.id))
             return contr
         else:
@@ -249,7 +249,7 @@ class ContractService(object):
 
         if response.status_code == 200:
             contr = Contract(response.json())
-            logging.info('Successfully terminated contract with id {}'.format(
+            logging.debug('Successfully terminated contract with id {}'.format(
                                 contr.id))
             return contr
         else:
@@ -272,7 +272,7 @@ class ContractService(object):
 
         if response.status_code == 200:
             contract = Contract(response.json())
-            logging.info('Successfully signed contract with id {}'.format(
+            logging.debug('Successfully signed contract with id {}'.format(
                                 contract.id))
             return contract
         else:
@@ -292,7 +292,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} parties'.format(len(response.json())))
+            logging.debug('Found {} parties'.format(len(response.json())))
             parties = []
             for p in response.json():
                 parties.append(Party(p))
@@ -323,7 +323,7 @@ class ContractService(object):
 
         if response.status_code == 200:
             prt = Party(response.json())
-            logging.info('Successfully created party with id {}'.format(prt.id))
+            logging.debug('Successfully created party with id {}'.format(prt.id))
             return prt
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -343,7 +343,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found party wiht id {} from contract {}'
+            logging.debug('Found party wiht id {} from contract {}'
                                             .format(contractId, partyId))
             return Party(response.json())
         else:
@@ -376,7 +376,7 @@ class ContractService(object):
 
         if response.status_code is 200:
             prt = Party(response.json())
-            logging.info('Successfully modified party with the id {}'
+            logging.debug('Successfully modified party with the id {}'
                         .format(prt.id))
             return prt
         else:
@@ -396,7 +396,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted party with id {}'
+            logging.debug('Successfully deleted party with id {}'
                                                         .format(partyId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -414,7 +414,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} signers'.format(len(response.json())))
+            logging.debug('Found {} signers'.format(len(response.json())))
             signers = []
             for s in response.json():
                 signers.append(Signer(s))
@@ -446,7 +446,7 @@ class ContractService(object):
 
         if response.status_code == 200:
             s = Signer(response.json())
-            logging.info('Successfully created signer with id {}'.format(s.id))
+            logging.debug('Successfully created signer with id {}'.format(s.id))
             return s
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -468,7 +468,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found signer wiht id {} from party {}'
+            logging.debug('Found signer wiht id {} from party {}'
                                         .format(signerId, partyId))
             return Signer(response.json())
         else:
@@ -503,7 +503,7 @@ class ContractService(object):
 
         if response.status_code is 200:
             s = Signer(response.json())
-            logging.info('Successfully modified signer with the id {}'
+            logging.debug('Successfully modified signer with the id {}'
                         .format(s.id))
             return s
         else:
@@ -525,7 +525,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted signer with id {} from party {}'
+            logging.debug('Successfully deleted signer with id {} from party {}'
                                         .format(signerId, partyId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -545,7 +545,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} contacts'.format(len(response.json())))
+            logging.debug('Found {} contacts'.format(len(response.json())))
             contacts = []
             for c in response.json():
                 contacts.append(PartyContact(c))
@@ -577,7 +577,7 @@ class ContractService(object):
 
         if response.status_code == 200:
             c = PartyContact(response.json())
-            logging.info('Successfully created contact with id {}'.format(c.id))
+            logging.debug('Successfully created contact with id {}'.format(c.id))
             return c
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -599,7 +599,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found contact wiht id {} from party {}'
+            logging.debug('Found contact wiht id {} from party {}'
                                         .format(contactId, partyId))
             return PartyContact(response.json())
         else:
@@ -638,7 +638,7 @@ class ContractService(object):
 
         if response.status_code is 200:
             c = PartyContact(response.json())
-            logging.info('Successfully modified contact with the id {}'
+            logging.debug('Successfully modified contact with the id {}'
                         .format(c.id))
             return c
         else:
@@ -660,7 +660,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted contact with id {} from party {}'
+            logging.debug('Successfully deleted contact with id {} from party {}'
                                         .format(contactId, partyId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -679,7 +679,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found {} appendices'.format(len(response.json())))
+            logging.debug('Found {} appendices'.format(len(response.json())))
             appendices = []
             for a in response.json():
                 appendices.append(Appendix(a))
@@ -710,7 +710,7 @@ class ContractService(object):
 
         if response.status_code == 201:
             a = Appendix(response.json())
-            logging.info('Successfully created appendix {}'.format(a.id))
+            logging.debug('Successfully created appendix {}'.format(a.id))
             return a
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -731,7 +731,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found appendix wiht id {} from contract {}'
+            logging.debug('Found appendix wiht id {} from contract {}'
                                             .format(appendixId, contractId))
             return Appendix(response.json())
         else:
@@ -765,7 +765,7 @@ class ContractService(object):
 
         if response.status_code is 200:
             a = Appendix(response.json())
-            logging.info('Successfully modified appendix with the id {}'
+            logging.debug('Successfully modified appendix with the id {}'
                         .format(a.id))
             return a
         else:
@@ -786,7 +786,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code is 204:
-            logging.info('Successfully deleted appendix with id {}'
+            logging.debug('Successfully deleted appendix with id {}'
                                         .format(appendixId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -805,7 +805,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code is 200:
-            logging.info('Found content from contract with id {}'
+            logging.debug('Found content from contract with id {}'
                                                 .format(contractId))
             return ContractContent(response.json())
         else:
@@ -834,7 +834,7 @@ class ContractService(object):
                                     auth=self._auth)
 
         if response.status_code is 200:
-            logging.info(
+            logging.debug(
                 'Successfully modified content of the contract with the id {}'
                         .format(contractId))
             return ContractContent(response.json())
@@ -858,7 +858,7 @@ class ContractService(object):
                                            auth=self._auth)
 
         if response.status_code == 200:
-            logging.info(
+            logging.debug(
             'Successfully changed order of appendices in contract with id {}'
                                     .format(contractId))
             appendices = []
@@ -885,7 +885,7 @@ class ContractService(object):
                                           auth=self._auth)
 
         if response.status_code == 200:
-            logging.info(
+            logging.debug(
                     'Successfully got the file from appendix with id {}'
                                     .format(appendixId))
             return response.content
@@ -908,7 +908,7 @@ class ContractService(object):
                                           auth=self._auth)
 
         if response.status_code == 204:
-            logging.info(
+            logging.debug(
                     'Successfully uploaded the file to appendix with id {}'
                                     .format(appendixId))
         else:
@@ -928,7 +928,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code == 204:
-            logging.info(
+            logging.debug(
                 'Successfully deleted file from the appendix with id {}'
                                     .format(appendixId))
         else:
@@ -948,7 +948,7 @@ class ContractService(object):
         response = self._session.get(uri, headers=self._header, auth=self._auth)
 
         if response.status_code == 200:
-            logging.info('Successfully got the file from the contract {}'
+            logging.debug('Successfully got the file from the contract {}'
                                     .format(contractId))
             return response.content
         else:
@@ -969,7 +969,7 @@ class ContractService(object):
                                           auth=self._auth)
 
         if response.status_code == 204:
-            logging.info('Successfully uploaded the file to the contract {}'
+            logging.debug('Successfully uploaded the file to the contract {}'
                                     .format(contractId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
@@ -987,7 +987,7 @@ class ContractService(object):
                                              auth=self._auth)
 
         if response.status_code == 204:
-            logging.info('Successfully deleted file from the contract {}'
+            logging.debug('Successfully deleted file from the contract {}'
                                     .format(contractId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
